from coralillo import Engine, Form, fields
import unittest

nrm = Engine()


class Ship(Form):
    name = fields.Text()
    code = fields.Text()

    class Meta:
        engine = nrm


class FormTestCase(unittest.TestCase):

    def test_init_form(self):
        obj = Ship()

        self.assertIsNone(obj.name)
        self.assertIsNone(obj.code)


if __name__ == '__main__':
    unittest.main()



import unittest
from coralillo import Model, Form, Engine, fields
from coralillo.validation import validation_rule
from coralillo.errors import ValidationErrors, InvalidFieldError

nrm = Engine()


class TestForm(Form):
    field1 = fields.Text()
    field2 = fields.Text()

    @validation_rule
    def enforce_fields(data):
        if (data.field1 is None and data.field2 is None) or \
            (data.field1 is not None and data.field2 is not None):
            raise InvalidFieldError(field='field1')

    class Meta:
        engine = nrm


class TestModel(Model):
    field1 = fields.Text(index=True, required=False, private=True)

    class Meta:
        engine = nrm


class ValidationTestCase(unittest.TestCase):

    def setUp(self):
        nrm.lua.drop(args=['*'])

    def test_validate_with_custom_rules(self):
        with self.assertRaises(ValidationErrors):
            TestForm.validate(
                field1 = 'po',
                field2 = 'llo',
            )

        with self.assertRaises(ValidationErrors):
            TestForm.validate()

    def test_can_have_many_uniques_with_null_value(self):
        m1 = TestModel.validate().save()
        self.assertIsNone(m1.field1)

        m2 = TestModel.validate().save()
        self.assertIsNone(m2.field1)


if __name__ == '__main__':
    unittest.main()



import unittest
from coralillo.datamodel import Location


class DatamodelTestCase(unittest.TestCase):

    def test_location(self):
        p1 = Location(-103.33465,20.71437)
        p2 = Location(-103.31886,20.69446)
        
        self.assertEqual(p1.distance(p2), 2756.575438006388)

if __name__ == '__main__':
    unittest.main()
